@@ -16,7 +16,7 @@ use Lemonldap::NG::Portal::Main::Constants qw(
 );
 use Lemonldap::NG::Common::Util qw/display2F/;
 
-our $VERSION = '2.19.0';
+our $VERSION = '2.21.0';
 
 extends qw(
   Lemonldap::NG::Portal::Main::SecondFactor
@@ -47,12 +47,12 @@ sub run {
     $self->logger->debug( $self->prefix . '2f: generate form' );
 
     # Prepare form
-    my ( $checkLogins, $stayConnected ) = $self->getFormParams($req);
     my $tmp = $self->p->sendHtml(
         $req,
         'totp2fcheck',
         params => {
-            TOKEN => $token,
+            TARGET => $self->p->relativeUrl( $req, 'totp2fcheck' ),
+            TOKEN  => $token,
             $self->get2fTplParams($req),
         }
     );
@@ -74,37 +74,34 @@ sub verify {
     }
 
     @totp2f = $self->find2fDevicesByType( $req, $session, $self->type );
-    my $_2fDevice;
-    foreach (@totp2f) {
-        if ( $_->{_secret} ) {
-            $secret    = $_->{_secret};
-            $_2fDevice = $_;
+
+    foreach my $device (@totp2f) {
+        $self->logger->debug( "Trying TOTP device " . display2F($device) );
+
+        if ( my $secret = $device->{_secret} ) {
+            my ( $r, $range ) = $self->verifyCode(
+                $self->conf->{totp2fInterval},
+                $self->conf->{totp2fRange},
+                $self->conf->{totp2fDigits},
+                $secret, $code
+            );
+            if ( $r == 1 ) {
+                $req->data->{_2fDevice}  = $device;
+                $req->data->{_2fLogInfo} = { range => $range };
+                return PE_OK;
+            }
+        }
+        else {
+            $self->logger->warn( "TOTP device "
+                  . display2F($device)
+                  . " has no secret for user $uid" );
         }
     }
-    unless ($secret) {
-        $self->logger->debug( $self->prefix . '2f: no secret found' );
-        return PE_BADOTP;
-    }
 
-    my ($r, $range) = $self->verifyCode(
-        $self->conf->{totp2fInterval},
-        $self->conf->{totp2fRange},
-        $self->conf->{totp2fDigits},
-        $secret, $code
-    );
-    return PE_ERROR if $r == -1;
-
-    if ($r) {
-        $self->userLogger->info("Codes match at range $range");
-        $self->userLogger->info( "User $uid authenticated with 2F device: "
-              . display2F($_2fDevice) );
-        return PE_OK;
-    }
-    else {
-        $self->userLogger->notice(
-            $self->prefix . '2f: invalid attempt for ' . $uid );
-        return PE_BADOTP;
-    }
+    $self->userLogger->notice( $self->prefix
+          . '2f: code did not match any of the registered TOTP for '
+          . $uid );
+    return PE_BADOTP;
 }
 
 1;
