@@ -12,7 +12,7 @@ use Lemonldap::NG::Portal::Main::Constants qw(
   PE_SENDRESPONSE
 );
 
-our $VERSION = '2.17.0';
+our $VERSION = '2.21.0';
 
 extends 'Lemonldap::NG::Portal::Main::Auth';
 
@@ -50,7 +50,7 @@ sub init {
     $self->keytab("FILE:$file");
     $self->AjaxInitScript( '<script type="text/javascript" src="'
           . $self->p->staticPrefix
-          . '/common/js/kerberosChoice.js"></script>' )
+          . '/common/js/kerberosChoice.min.js"></script>' )
       if $self->conf->{krbByJs};
     return 1;
 }
