@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::Main::Constants qw(
   PE_REDIRECT
 );
 
-our $VERSION = '2.0.14';
+our $VERSION = '2.19.0';
 
 has cookieName => ( is => 'rw' );
 
@@ -90,7 +90,7 @@ sub goToPortal {
     $req->urldc(
         $self->conf->{remotePortal} . '?url='
           . encode_base64(
-            $self->conf->{portal}
+            $req->portal
               . ( $req->query_string ? '?' . $req->query_string : '' ),
             ''
           )
