@@ -1,13 +1,13 @@
 package Lemonldap::NG::Portal::Main::Process;
 
-our $VERSION = '2.19.0';
+our $VERSION = '2.21.0';
 
 package Lemonldap::NG::Portal::Main;
 
 use strict;
 use MIME::Base64;
-use POSIX qw(strftime);
-use Lemonldap::NG::Common::Util qw(isHiddenAttr);
+use POSIX                                  qw(strftime);
+use Lemonldap::NG::Common::Util            qw(isHiddenAttr);
 use Lemonldap::NG::Portal::Main::Constants qw(portalConsts);
 use URI;
 
@@ -161,21 +161,10 @@ sub controlUrl {
         }
         $req->{urldc} = URI->new( $req->{urldc} )->as_string;
 
-        # For logout request, test if Referer comes from an authorized site
-        my $tmp = (
-              $req->param('logout')
-            ? $req->referer
-            : $req->{urldc}
-        );
+        my $tmp = $req->urldc;
 
         # XSS attack
-        if (
-            $self->checkXSSAttack(
-                $req->param('logout') ? 'HTTP Referer' : 'urldc',
-                $req->{urldc}
-            )
-          )
-        {
+        if ( $self->checkXSSAttack( 'urldc', $req->{urldc} ) ) {
             delete $req->{urldc};
             return PE_BADURL;
         }
@@ -204,8 +193,7 @@ sub controlUrl {
         # Try to resolve alias
         my $originalVhost = $self->HANDLER->resolveAlias($vhost);
         $vhost = "$proto://$originalVhost";
-        $self->logger->debug( 'Required URL (param: '
-              . ( $req->param('logout') ? 'HTTP Referer'   : 'urldc' )
+        $self->logger->debug( 'Required URL (param: urldc'
               . ( $tmp ? " | value: $tmp | alias: $vhost)" : ')' ) );
 
         # If the target URL has an authLevel set in config, remember it.
@@ -224,8 +212,7 @@ sub controlUrl {
             $self->auditLog(
                 $req,
                 message => (
-                        "URL contains an unprotected host (param: "
-                      . ( $req->param('logout') ? 'HTTP Referer' : 'urldc' )
+                        "URL contains an unprotected host (param: urldc"
                       . " | value: $tmp | alias: $vhost)"
                 ),
                 code => "UNAUTHORIZED_REDIRECT",
@@ -262,6 +249,30 @@ sub checkUnauthLogout {
     return PE_OK;
 }
 
+sub eventLogout {
+    my ( $self, $req, $msg ) = @_;
+    bless $req, 'Lemonldap::NG::Portal::Main::Request';
+    $self->logger->debug("Receive a logout event");
+    $self->processHook( $req, 'eventLogout', $msg );
+    if ( $msg->{id} ) {
+        $self->logger->debug(" -> logout asked for $msg->{id}");
+        if ( my $session = HANDLER->retrieveSession( $req, $msg->{id} ) ) {
+            $req->id( $session->{_session_id} );
+            $req->pdata( {} );
+            $self->do( $req,
+                [ @{ $self->beforeLogout }, 'authLogout', 'deleteSession' ],
+                1 );
+        }
+        else {
+            $self->_unauthLogout($req);
+        }
+    }
+    else {
+        $self->logger->debug('Logout event without id');
+        $self->_unauthLogout($req);
+    }
+}
+
 sub checkCancel {
     my ( $self, $req ) = @_;
     if ( $req->param('cancel') ) {
@@ -457,10 +468,7 @@ sub authenticate {
     my ( $self, $req ) = @_;
     my $ret = $req->authResult( $self->_authentication->authenticate($req) );
     $self->logger->debug( " -> authResult = " . $req->authResult );
-    if ( $ret == PE_OK ) {
-        $req->{sessionInfo}->{_lastAuthnUTime} = time();
-        return $ret;
-    }
+    return $ret if $ret == PE_OK;
 
     # Store failed login into history
     $req->steps( [
@@ -481,6 +489,7 @@ sub authenticate {
 
 sub setAuthSessionInfo {
     my ( $self, $req ) = @_;
+    $req->{sessionInfo}->{_lastAuthnUTime} = time();
     my $ret = $self->_authentication->setAuthSessionInfo($req);
     if ( $ret == PE_OK
         and not( defined $req->sessionInfo->{authenticationLevel} ) )
@@ -670,6 +679,7 @@ sub buildCookie {
         ? $req->{sessionInfo}
         : $req->{userData}
     );
+    $req->data->{newAuth} = 1;
     $self->auditLog(
         $req,
         message => (
