@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::Main::Constants qw(
   PE_PP_INSUFFICIENT_PASSWORD_QUALITY
 );
 
-our $VERSION = '2.19.0';
+our $VERSION = '2.21.0';
 
 extends 'Lemonldap::NG::Portal::Main::Plugin';
 
@@ -80,6 +80,7 @@ sub init {
         ['POST']
     );
 
+    my $cacheTag = $self->p->cacheTag;
     $self->p->addPasswordPolicyDisplay(
         'ppolicy-checkentropy',
         {
@@ -90,8 +91,8 @@ sub init {
                 "CHECKENTROPY_REQUIRED_LEVEL" => $self->entropyRequiredLevel,
             },
             customHtml =>
-qq'<script type="text/javascript" src="$self->{p}->{staticPrefix}/common/js/entropy.min.js"></script>\n
-<link rel="stylesheet" type="text/css" href="$self->{p}->{staticPrefix}/common/css/entropy.min.css">',
+qq'<script type="text/javascript" src="$self->{p}->{staticPrefix}/common/js/entropy.min.js?v=$cacheTag"></script>\n
+<link rel="stylesheet" type="text/css" href="$self->{p}->{staticPrefix}/common/css/entropy.min.css?v=$cacheTag">',
             customHtmlAfter =>
 qq'<div id="entropybar" class="progress">\n
     <div class="progress-bar" role="progressbar" aria-valuenow="0" aria-valuemin="0" aria-valuemax="100"></div>\n
