@@ -7,9 +7,9 @@ use Lemonldap::NG::Portal::Main::Constants qw(
   PE_OK
 );
 
-our $VERSION = '2.0.12';
+our $VERSION = '2.19.0';
 
-extends 'Lemonldap::NG::Common::Module';
+extends 'Lemonldap::NG::Portal::Main::UserDB';
 
 # INITIALIZATION
 
@@ -50,9 +50,4 @@ sub setSessionInfo {
     return PE_OK;
 }
 
-# Does nothing
-sub setGroups {
-    return PE_OK;
-}
-
 1;
