@@ -4,9 +4,9 @@ use strict;
 use Mouse;
 use Lemonldap::NG::Portal::Main::Constants qw(PE_OK PE_MISSINGREQATTR);
 
-extends 'Lemonldap::NG::Common::Module';
+extends 'Lemonldap::NG::Portal::Main::UserDB';
 
-our $VERSION = '2.0.0';
+our $VERSION = '2.19.0';
 
 has vars => (
     is      => 'rw',
@@ -30,7 +30,13 @@ sub init {
 sub getUser {
 
     # All is done by Auth::Facebook
-    PE_OK;
+    return PE_OK;
+}
+
+sub findUser {
+
+    # Nothing to do here
+    return PE_OK;
 }
 
 sub setSessionInfo {
@@ -50,11 +56,8 @@ sub setSessionInfo {
             return PE_MISSINGREQATTR;
         }
     }
-    PE_OK;
-}
 
-sub setGroups {
-    PE_OK;
+    return PE_OK;
 }
 
 1;
